SystemOrganization addCategory: 'Orbeon_Persistence'!

Object subclass: #OrbeonDBObject
	instanceVariableNames: 'app form form_version created last_modified_time last_modified_by deleted properties'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

OrbeonDBObject subclass: #OrbeonDBDefinition
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

OrbeonDBDefinition subclass: #Orbeon_Form_Definition
	instanceVariableNames: 'form_metadata xml parentInstance permissions'
	classVariableNames: 'Storages'
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

!Orbeon_Form_Definition commentStamp: 'BrunoBB 07/29/2015 14:37' prior: 0!
CREATE TABLE orbeon_form_definition (
    created            TIMESTAMP(6),
    last_modified_time TIMESTAMP(6),
    last_modified_by   VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    app                VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    form               VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    form_version       INT NOT NULL,
    form_metadata      VARCHAR(4000)                             COLLATE utf8_bin,
    deleted            CHAR(1)                                   COLLATE utf8_bin        NOT NULL,
    xml                MEDIUMTEXT             CHARACTER SET utf8 COLLATE utf8_unicode_ci
)   ENGINE = InnoDB;


parentInstance - holds the Orbeon_Form_Data that originated the Form Definition after being published. In Orbeon before a form is published is stored as an Orbeon_Form_Data, only when the saved form is published an instance of Orbeon_Form_Definition is created. This instance variable holds the orginal Orbeon_Form_Data that originated the Orbeon_Form_Definition.!

!Orbeon_Form_Definition class methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 14:48'!
getAllFormDefinitions
	| definitions |

	definitions := OrderedCollection new.

	self storages do: [:storage | storage definitions do: [:eachDict | definitions addAll: eachDict]].

	^definitions! !

!Orbeon_Form_Definition class methodsFor: 'other' stamp: 'BrunoBB 08/16/2015 18:14'!
getAllLatestFormDefinitions
	| definitions |

	definitions := OrderedCollection new.

	self storages do: [:storage | storage definitions keys do: [:formName | definitions add: (storage getLastDefinitionOf: formName)]].

	^definitions! !

!Orbeon_Form_Definition class methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 12:43'!
getLatestFormDefinition: formName app: app
	"The receiver answer the latest published version of the form name <formName> in the application <app>"
	| storage |

	storage := self storages at: app ifAbsent: [^nil].

	^storage getLastDefinitionOf: formName! !

!Orbeon_Form_Definition class methodsFor: 'other' stamp: 'BrunoBB 08/14/2015 12:30'!
getLatestFormDefinitionVersion: formName app: app
	"The receiver answer the latest published version of the form name <formName> in the application <app>"
	| storage |

	storage := self storages at: app ifAbsent: [^0].

	^storage getLastestVersionNumberOf: formName! !

!Orbeon_Form_Definition class methodsFor: 'other' stamp: 'BrunoBB 08/13/2015 11:08'!
getStringDictionaryOfAll
	| definitions |

	definitions := Dictionary new.

	self storages keysAndValuesDo: [:key :storage | definitions at: key put: storage definitionKeys].

	^definitions! !

!Orbeon_Form_Definition class methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 11:48'!
initializeStorages

	Storages := Dictionary new.

	^Storages! !

!Orbeon_Form_Definition class methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 11:39'!
storages

	Storages ifNil: [Storages := Dictionary new].

	^Storages! !

!Orbeon_Form_Definition class methodsFor: 'other' stamp: 'BrunoBB 08/16/2015 18:41'!
unpublish: formName in: app
	| storage |

	storage := self storages at: app ifAbsent: [^nil].

	^storage removeAllDefinitionsNamed: formName! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/14/2015 13:47'!
addAnyOnePermissionsFromString: stringOperations

	(stringOperations subStrings: ' ') do: [:oper | permissions add: oper to: 'anyone']! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/14/2015 14:25'!
addPermissionsFromString: stringOperations using: permissionNode
	| subNode |

	subNode := permissionNode nodes first.
	
	(stringOperations subStrings: ' ') do: [:oper | 
		(subNode name = 'user-role')
		ifFalse: [self permissions add: oper to: subNode name]
		"-any-of- can have more than one role"
		ifTrue: [((subNode attributeAt: 'any-of') subStrings: ' ') do: [:rol | self permissions add: oper to: rol]] 
	].! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 11:43'!
addToStorage

	^self storage addDefinition: self! !

!Orbeon_Form_Definition methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:31'!
form_metadata
	^form_metadata! !

!Orbeon_Form_Definition methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:31'!
form_metadata: newValue
	form_metadata := newValue! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/14/2015 13:17'!
hasPermissionsEnabled

	^permissions isEnabled! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/14/2015 13:17'!
initialize

	super initialize.

	permissions := OrbeonPermissions new.! !

!Orbeon_Form_Definition methodsFor: 'Accessing' stamp: 'BrunoBB 08/10/2015 10:31'!
parentInstance
	^parentInstance! !

!Orbeon_Form_Definition methodsFor: 'Updating' stamp: 'BrunoBB 08/14/2015 12:12'!
parentInstance: anOrbeon_Form_Data

	parentInstance := anOrbeon_Form_Data.! !

!Orbeon_Form_Definition methodsFor: 'Accessing' stamp: 'BrunoBB 08/14/2015 14:21'!
permissions
	^permissions! !

!Orbeon_Form_Definition methodsFor: 'Updating' stamp: 'BrunoBB 08/14/2015 14:21'!
permissions: newValue
	permissions := newValue! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/17/2015 13:02'!
publish

	^self setAvailableNodeWith: 'true'! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/17/2015 13:57'!
setAvailableNodeWith: aBooleanString
	| xmlDocument metadata available newXML |

	xmlDocument := XMLDOMParser parse: xml.
	metadata := xmlDocument allElementsNamed: 'metadata'.
	metadata isEmpty ifTrue: [^self].
	metadata := metadata last.

	metadata removeNodes: (metadata allElementsNamed: 'available').

	available := XMLElement named: 'available'.
	available addContent: aBooleanString.
	metadata addNode: available.

	newXML := String new.
	xmlDocument printOn: (PrintStream on: newXML).
	xml := newXML.! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/14/2015 13:21'!
setMetadata
	| xmlDocument title description |

	xmlDocument := XMLDOMParser parse: xml.

	app := (xmlDocument findElementNamed: 'application-name')
		ifNotNil: [:value | value strings isEmpty ifTrue: [''] ifFalse: [value strings last]]
		ifNil: [''].
	form := (xmlDocument findElementNamed: 'form-name')
		ifNotNil: [:value | value strings isEmpty ifTrue: [''] ifFalse: [value strings last]]
		ifNil: [''].

	title := (xmlDocument findElementNamed: 'title')
		ifNotNil: [:value | value strings isEmpty ifTrue: [''] ifFalse: [value strings last]]
		ifNil: [''].
	description := (xmlDocument findElementNamed: 'description')
		ifNotNil: [:value | value strings isEmpty ifTrue: [''] ifFalse: [value strings last]]
		ifNil: [''].

	title ifNotNil: [self setProterty: 'title' with: title].
	description ifNotNil: [self setProterty: 'description' with: description].

	self setPermissionWith: xmlDocument! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/14/2015 14:53'!
setPermissionWith: xmlDocument
	| permissionNodes |

	permissionNodes := xmlDocument allElementsNamed: 'permission'.
	permissions isEnabled: permissionNodes notEmpty.

	permissionNodes do: [:node |
		node hasContentNodes " -anyone- role does not have content"
		ifTrue: [self addPermissionsFromString: (node attributeAt: 'operations') using: node]
		ifFalse: [self addAnyOnePermissionsFromString: (node attributeAt: 'operations')] 
	].! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 11:52'!
storage

	^self class storages at: app ifAbsentPut: [OrbeonDefinitionStorage new app: app]! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/17/2015 13:15'!
switchAvailable

	(self available = 'true') 
	ifTrue: [self unpublish.
		^self available: 'false'].

	self publish.
	^self available: 'true'! !

!Orbeon_Form_Definition methodsFor: 'other' stamp: 'BrunoBB 08/17/2015 13:02'!
unpublish

	^self setAvailableNodeWith: 'false'! !

!Orbeon_Form_Definition methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:31'!
xml
	^xml! !

!Orbeon_Form_Definition methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:31'!
xml: newValue
	xml := newValue! !

OrbeonDBDefinition subclass: #Orbeon_Form_Definition_Attach
	instanceVariableNames: 'file_name file_content'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

!Orbeon_Form_Definition_Attach commentStamp: 'BrunoBB 07/29/2015 14:37' prior: 0!
CREATE TABLE orbeon_form_definition_attach (
    created            TIMESTAMP(6),
    last_modified_time TIMESTAMP(6),
    last_modified_by   VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    app                VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    form               VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    form_version       INT NOT NULL,
    deleted            CHAR(1)                                   COLLATE utf8_bin        NOT NULL,
    file_name          VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    file_content       LONGBLOB
)   ENGINE = InnoDB;!

!Orbeon_Form_Definition_Attach methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:31'!
file_content
	^file_content! !

!Orbeon_Form_Definition_Attach methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:31'!
file_content: newValue
	file_content := newValue! !

!Orbeon_Form_Definition_Attach methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:31'!
file_name
	^file_name! !

!Orbeon_Form_Definition_Attach methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:31'!
file_name: newValue
	file_name := newValue! !

!OrbeonDBDefinition methodsFor: 'other' stamp: 'BrunoBB 08/07/2015 11:17'!
addToCache

	^self class cache add: self! !

OrbeonDBObject subclass: #OrbeonDBInstance
	instanceVariableNames: 'document_id username groupname draft'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

OrbeonDBInstance subclass: #Orbeon_Form_Data
	instanceVariableNames: 'xml isDefinition definition'
	classVariableNames: 'Storages'
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

!Orbeon_Form_Data commentStamp: 'BrunoBB 07/29/2015 14:37' prior: 0!
CREATE TABLE orbeon_form_data (
    created            TIMESTAMP(6),
    last_modified_time TIMESTAMP(6),
    last_modified_by   VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    username           VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    groupname          VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    app                VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    form               VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    form_version       INT NOT NULL,
    document_id        VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    draft              CHAR(1)                                   COLLATE utf8_bin        NOT NULL,
    deleted            CHAR(1)                                   COLLATE utf8_bin        NOT NULL,
    xml                MEDIUMTEXT             CHARACTER SET utf8 COLLATE utf8_unicode_ci
)   ENGINE = InnoDB;!

!Orbeon_Form_Data class methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 13:55'!
getAllFormDefinitions
	| definitions |

	definitions := OrderedCollection new.

	self storages do: [:storage | storage definitions do: [:eachDict | definitions addAll: eachDict]].

	^definitions! !

!Orbeon_Form_Data class methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 14:29'!
getAllFormInstances
	| instances |

	instances := OrderedCollection new.

	self storages do: [:storage | storage instances do: [:eachDict | instances addAll: eachDict]].

	^instances! !

!Orbeon_Form_Data class methodsFor: 'definitions' stamp: 'BrunoBB 08/13/2015 14:30'!
getFormDefinition: formName in: app withId: id

	^self getFormDefinition: formName in: app withId: id ifNone: [nil]! !

!Orbeon_Form_Data class methodsFor: 'definitions' stamp: 'BrunoBB 08/13/2015 14:29'!
getFormDefinition: formName in: app withId: id ifNone: aBlock

	^(self storages at: app ifAbsent: [^nil]) getFormDefinition: formName withId: id ifNone: aBlock! !

!Orbeon_Form_Data class methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 13:34'!
getFormDefinitionsOf: formName in: app

	^(self storages at: app ifAbsent: [^#()]) getAllFormDefinitionsOf: formName! !

!Orbeon_Form_Data class methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 13:23'!
getFormDefinitionWithId: id

	^self getFormDefinitionWithId: id ifNone: [nil]! !

!Orbeon_Form_Data class methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 13:23'!
getFormDefinitionWithId: id ifNone: aBlock

	self storages do: [:storage | (storage getAnyFormDefinitionWithId: id) ifNotNil: [:form | ^form]].

	^aBlock value! !

!Orbeon_Form_Data class methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 12:08'!
getFormDraft: formName in: app withId: id

	^self getFormDraft: formName in: app withId: id ifNone: [nil]! !

!Orbeon_Form_Data class methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 12:08'!
getFormDraft: formName in: app withId: id ifNone: aBlock

	^(self storages at: app ifAbsent: [^aBlock value]) getFormDraft: formName withId: id ifNone: aBlock! !

!Orbeon_Form_Data class methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 12:22'!
getFormDraftsOf: formName in: app

	^(self storages at: app ifAbsent: [^#()]) getAllFormDraftsOf: formName! !

!Orbeon_Form_Data class methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 13:19'!
getFormInstance: formName in: app withId: id

	^self getFormInstance: formName in: app withId: id ifNone: [nil]! !

!Orbeon_Form_Data class methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 13:20'!
getFormInstance: formName in: app withId: id ifNone: aBlock

	^(self storages at: app ifAbsent: [^aBlock value]) getFormInstance: formName withId: id ifNone: aBlock! !

!Orbeon_Form_Data class methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 13:34'!
getFormInstancesOf: formName in: app

	^(self storages at: app ifAbsent: [^#()]) getAllFormInstancesOf: formName! !

!Orbeon_Form_Data class methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 13:23'!
getFormInstanceWithId: id

	^self getFormInstanceWithId: id ifNone: [nil]! !

!Orbeon_Form_Data class methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 13:21'!
getFormInstanceWithId: id ifNone: aBlock

	self storages do: [:storage | (storage getAnyFormInstanceWithId: id) ifNotNil: [:form | ^form]].

	^aBlock value! !

!Orbeon_Form_Data class methodsFor: 'other' stamp: 'BrunoBB 08/13/2015 11:09'!
getStringDictionaryOfAll
	| definitions |

	definitions := Dictionary new.

	self storages keysAndValuesDo: [:key :storage | definitions at: key put: storage definitionKeys].

	^definitions! !

!Orbeon_Form_Data class methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 11:48'!
initializeStorages

	Storages := Dictionary new.

	^Storages! !

!Orbeon_Form_Data class methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 13:16'!
logicalRemoveFormDefinitionWithId: id ifAbsent: aBlock

	self storages do: [:storage | (storage getAnyFormDefinitionWithId: id) ifNotNil: [:form | ^form logicalRemove]].! !

!Orbeon_Form_Data class methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 12:11'!
logicalRemoveFormDraftWithId: id ifAbsent: aBlock

	self storages do: [:storage | (storage getAnyFormDraftWithId: id) ifNotNil: [:form | ^form logicalRemove]].! !

!Orbeon_Form_Data class methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 13:11'!
logicalRemoveFormInstanceWithId: id ifAbsent: aBlock

	self storages do: [:storage | (storage getAnyFormInstanceWithId: id) ifNotNil: [:form | ^form logicalRemove]].! !

!Orbeon_Form_Data class methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 15:47'!
removeFormDraftWithId: id form: formName app: app ifAbsent: aBlock

	^(self storages at: app ifAbsent: [^aBlock value]) removeDraftWithId: id in: formName! !

!Orbeon_Form_Data class methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 11:38'!
storages

	Storages ifNil: [Storages := Dictionary new].

	^Storages! !

!Orbeon_Form_Data class methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 14:53'!
totalSize
	| totalSize |

	totalSize := 0.

	self storages do: [:each | totalSize := totalSize + each totalSize].

	^totalSize! !

!Orbeon_Form_Data methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 11:42'!
addToStorage

	^isDefinition
	ifTrue: [self storage addSavedDefinition: self]
	ifFalse: [self storage addInstance: self]! !

!Orbeon_Form_Data methodsFor: 'other' stamp: 'BrunoBB 08/16/2015 12:02'!
addToStorageAsDraft

	^self storage addDraft: self! !

!Orbeon_Form_Data methodsFor: 'Accessing' stamp: 'BrunoBB 08/14/2015 15:05'!
definition
	^definition! !

!Orbeon_Form_Data methodsFor: 'Updating' stamp: 'BrunoBB 08/14/2015 15:05'!
definition: newValue
	definition := newValue! !

!Orbeon_Form_Data methodsFor: 'other' stamp: 'BrunoBB 08/08/2015 12:39'!
getValueOfFields: collectionOfNames
	| xmlDocument values |

	xmlDocument := XMLDOMParser parse: xml.
	values := OrderedCollection new.
	
	values := collectionOfNames collect: [:each | 
					(xmlDocument findElementNamed: each) 
					ifNotNil: [:value | value strings isEmpty ifTrue: [''] ifFalse: [value strings last]]
					ifNil: [''].].
	^values! !

!Orbeon_Form_Data methodsFor: 'permissions' stamp: 'BrunoBB 08/16/2015 16:31'!
hasRole: aRoleName createAccessUsing: anOrbeonPermissions

	anOrbeonPermissions isEnabled ifFalse: [^true]. "if permissions are NOT enabled then it has ALL permissions"

	(groupname = aRoleName) ifFalse: [^anOrbeonPermissions hasCreateAccess: aRoleName].

	^anOrbeonPermissions hasCreateAccess: 'group-member'! !

!Orbeon_Form_Data methodsFor: 'permissions' stamp: 'BrunoBB 08/16/2015 16:31'!
hasRole: aRoleName deleteAccessUsing: anOrbeonPermissions

	anOrbeonPermissions isEnabled ifFalse: [^true]. "if permissions are NOT enabled then it has ALL permissions"

	(groupname = aRoleName) ifFalse: [^anOrbeonPermissions hasDeleteAccess: aRoleName].

	^anOrbeonPermissions hasDeleteAccess: 'group-member'! !

!Orbeon_Form_Data methodsFor: 'permissions' stamp: 'BrunoBB 08/15/2015 14:48'!
hasRole: aRoleName readAccessUsing: anOrbeonPermissions

	anOrbeonPermissions isEnabled ifFalse: [^true]. "if permissions are NOT enabled then it has ALL permissions"

	(groupname = aRoleName) ifFalse: [^anOrbeonPermissions hasReadAccess: aRoleName].

	^anOrbeonPermissions hasReadAccess: 'group-member'! !

!Orbeon_Form_Data methodsFor: 'permissions' stamp: 'BrunoBB 08/16/2015 16:30'!
hasRole: aRoleName updateAccessUsing: anOrbeonPermissions

	anOrbeonPermissions isEnabled ifFalse: [^true]. "if permissions are NOT enabled then it has ALL permissions"

	(groupname = aRoleName) ifFalse: [^anOrbeonPermissions hasUpdateAccess: aRoleName].

	^anOrbeonPermissions hasUpdateAccess: 'group-member'! !

!Orbeon_Form_Data methodsFor: 'permissions' stamp: 'BrunoBB 08/16/2015 16:29'!
hasUser: aUserName createAccessUsing: anOrbeonPermissions

	anOrbeonPermissions isEnabled ifFalse: [^true]. "if permissions are NOT enabled then it has ALL permissions"

	^(aUserName = username) and: [anOrbeonPermissions hasCreateAccess: 'owner']! !

!Orbeon_Form_Data methodsFor: 'permissions' stamp: 'BrunoBB 08/16/2015 16:29'!
hasUser: aUserName deleteAccessUsing: anOrbeonPermissions

	anOrbeonPermissions isEnabled ifFalse: [^true]. "if permissions are NOT enabled then it has ALL permissions"

	^(aUserName = username) and: [anOrbeonPermissions hasDeleteAccess: 'owner']! !

!Orbeon_Form_Data methodsFor: 'permissions' stamp: 'BrunoBB 08/15/2015 14:04'!
hasUser: aUserName readAccessUsing: anOrbeonPermissions

	anOrbeonPermissions isEnabled ifFalse: [^true]. "if permissions are NOT enabled then it has ALL permissions"

	^(aUserName = username) and: [anOrbeonPermissions hasReadAccess: 'owner']! !

!Orbeon_Form_Data methodsFor: 'permissions' stamp: 'BrunoBB 08/16/2015 16:28'!
hasUser: aUserName updateAccessUsing: anOrbeonPermissions

	anOrbeonPermissions isEnabled ifFalse: [^true]. "if permissions are NOT enabled then it has ALL permissions"

	^(aUserName = username) and: [anOrbeonPermissions hasUpdateAccess: 'owner']! !

!Orbeon_Form_Data methodsFor: 'other' stamp: 'BrunoBB 08/07/2015 10:29'!
initialize

	super initialize.

	xml := ''.
"when a Form Definition is saved (but not published) is save as Data, ONLY in this case <isDefinition> will be <true>"
	isDefinition := false.! !

!Orbeon_Form_Data methodsFor: 'Accessing' stamp: 'BrunoBB 08/07/2015 10:28'!
isDefinition
	^isDefinition! !

!Orbeon_Form_Data methodsFor: 'Updating' stamp: 'BrunoBB 08/07/2015 10:28'!
isDefinition: newValue
	isDefinition := newValue! !

!Orbeon_Form_Data methodsFor: 'other' stamp: 'BrunoBB 08/16/2015 12:05'!
removeFromStorageAsDraft

	^self storage removeDraft: self! !

!Orbeon_Form_Data methodsFor: 'other' stamp: 'BrunoBB 08/08/2015 13:53'!
satisfyQuery: collectionOfOrbeonQueryNode
	| queryFields |

	queryFields := self getValueOfFields: (collectionOfOrbeonQueryNode collect: [:each | each name]).

	collectionOfOrbeonQueryNode keysAndValuesDo: [:index :node |
		(node value = (queryFields at: index)) ifFalse: [^false]].


	^true! !

!Orbeon_Form_Data methodsFor: 'other' stamp: 'BrunoBB 08/07/2015 11:19'!
setMetadata
	| xmlDocument title description |

	xmlDocument := XMLDOMParser parse: xml.

	app := (xmlDocument findElementNamed: 'application-name')
		ifNotNil: [:value | value strings isEmpty ifTrue: [''] ifFalse: [value strings last]]
		ifNil: [''].
	form := (xmlDocument findElementNamed: 'form-name')
		ifNotNil: [:value | value strings isEmpty ifTrue: [''] ifFalse: [value strings last]]
		ifNil: [''].

	title := (xmlDocument findElementNamed: 'title')
		ifNotNil: [:value | value strings isEmpty ifTrue: [''] ifFalse: [value strings last]]
		ifNil: [''].
	description := (xmlDocument findElementNamed: 'description')
		ifNotNil: [:value | value strings isEmpty ifTrue: [''] ifFalse: [value strings last]]
		ifNil: [''].

	title ifNotNil: [self setProterty: 'title' with: title].
	description ifNotNil: [self setProterty: 'description' with: description].! !

!Orbeon_Form_Data methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 11:52'!
storage

	^self class storages at: app ifAbsentPut: [OrbeonDataStorage new app: app]! !

!Orbeon_Form_Data methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:31'!
xml
	^xml! !

!Orbeon_Form_Data methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:31'!
xml: newValue
	xml := newValue! !

OrbeonDBInstance subclass: #Orbeon_Form_Data_Attach
	instanceVariableNames: 'file_name file_content'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

!Orbeon_Form_Data_Attach commentStamp: 'BrunoBB 07/29/2015 14:37' prior: 0!
CREATE TABLE orbeon_form_data_attach (
    created            TIMESTAMP(6),
    last_modified_time TIMESTAMP(6),
    last_modified_by   VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    username           VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    groupname          VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    app                VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    form               VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    form_version       INT NOT NULL,
    document_id        VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    draft              CHAR(1)                                   COLLATE utf8_bin        NOT NULL,
    deleted            CHAR(1)                                   COLLATE utf8_bin        NOT NULL,
    file_name          VARCHAR(255)           CHARACTER SET utf8 COLLATE utf8_bin,
    file_content       LONGBLOB
)   ENGINE = InnoDB;!

!Orbeon_Form_Data_Attach methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:35'!
file_content
	^file_content! !

!Orbeon_Form_Data_Attach methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:35'!
file_content: newValue
	file_content := newValue! !

!Orbeon_Form_Data_Attach methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:35'!
file_name
	^file_name! !

!Orbeon_Form_Data_Attach methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:35'!
file_name: newValue
	file_name := newValue! !

!OrbeonDBInstance methodsFor: 'other' stamp: 'BrunoBB 08/04/2015 14:54'!
addToCache

	^self class cache at: document_id put: self! !

!OrbeonDBInstance methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:35'!
document_id
	^document_id! !

!OrbeonDBInstance methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:35'!
document_id: newValue
	document_id := newValue! !

!OrbeonDBInstance methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:35'!
draft
	^draft! !

!OrbeonDBInstance methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:35'!
draft: newValue
	draft := newValue! !

!OrbeonDBInstance methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:35'!
groupname
	^groupname! !

!OrbeonDBInstance methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:35'!
groupname: newValue
	groupname := newValue! !

!OrbeonDBInstance methodsFor: 'other' stamp: 'BrunoBB 08/04/2015 14:57'!
initialize

	super initialize.

	document_id := ''.
	username := ''.
	groupname := ''.
	draft := 'N'.! !

!OrbeonDBInstance methodsFor: 'other' stamp: 'BrunoBB 08/15/2015 15:59'!
printDraft

	(draft = 'N') ifTrue: [^'false'].

	^'true'! !

!OrbeonDBInstance methodsFor: 'other' stamp: 'BrunoBB 08/04/2015 14:55'!
removeFromCache

	^self class cache removeKey: document_id ifAbsent: []! !

!OrbeonDBInstance methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:35'!
username
	^username! !

!OrbeonDBInstance methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:35'!
username: newValue
	username := newValue! !

!OrbeonDBObject methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:29'!
app
	^app! !

!OrbeonDBObject methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:29'!
app: newValue
	app := newValue! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/17/2015 11:59'!
available

	^self getProterty: 'available'! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/30/2015 14:47'!
available: aBooleanString

	^self setProperty: 'available' with: aBooleanString! !

!OrbeonDBObject methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:29'!
created
	^created! !

!OrbeonDBObject methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:29'!
created: newValue
	created := newValue! !

!OrbeonDBObject methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:29'!
deleted
	^deleted! !

!OrbeonDBObject methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:29'!
deleted: newValue
	deleted := newValue! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/16/2015 18:08'!
description

	^self getProterty: 'description'! !

!OrbeonDBObject methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:29'!
form
	^form! !

!OrbeonDBObject methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:29'!
form_version
	^form_version! !

!OrbeonDBObject methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:29'!
form_version: newValue
	form_version := newValue! !

!OrbeonDBObject methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:29'!
form: newValue
	form := newValue! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/06/2015 11:04'!
getProterty: propertieName

	^self getProterty: propertieName ifNone: ['']! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/06/2015 10:42'!
getProterty: propertieName ifNone: aBlock

	^properties at: propertieName ifAbsent: aBlock! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/06/2015 10:41'!
includesProterty: propertieName

	^properties includesKey: propertieName! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/06/2015 10:41'!
initialize

	super initialize.

	app := ''.
	form := ''.
	form_version := 0.
	created := DateTime now.
	last_modified_time := DateTime now.
	last_modified_by := ''.
	deleted := 'N'.
	properties := Dictionary new.! !

!OrbeonDBObject methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:29'!
last_modified_by
	^last_modified_by! !

!OrbeonDBObject methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:29'!
last_modified_by: newValue
	last_modified_by := newValue! !

!OrbeonDBObject methodsFor: 'Accessing' stamp: 'BrunoBB 07/29/2015 14:29'!
last_modified_time
	^last_modified_time! !

!OrbeonDBObject methodsFor: 'Updating' stamp: 'BrunoBB 07/29/2015 14:29'!
last_modified_time: newValue
	last_modified_time := newValue! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 14:18'!
logicalRemove

	^deleted := 'Y'! !

!OrbeonDBObject methodsFor: 'Accessing' stamp: 'BrunoBB 08/06/2015 10:40'!
properties
	^properties! !

!OrbeonDBObject methodsFor: 'Updating' stamp: 'BrunoBB 08/06/2015 10:40'!
properties: newValue
	properties := newValue! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/06/2015 10:41'!
setProterty: propertieName with: value

	^properties at: propertieName put: value! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/16/2015 18:09'!
title

	^self getProterty: 'title'! !

!OrbeonDBObject methodsFor: 'other' stamp: 'BrunoBB 08/04/2015 15:09'!
updateLastModifiedTime

	last_modified_time := DateTime now.! !

Object subclass: #OrbeonServiceInteraction
	instanceVariableNames: 'headers xml parameters id valid'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

OrbeonServiceInteraction class
	instanceVariableNames: 'cache'!

!OrbeonServiceInteraction class methodsFor: 'Accessing' stamp: 'BrunoBB 08/04/2015 14:07'!
cache

	^cache! !

!OrbeonServiceInteraction class methodsFor: 'Accessing' stamp: 'BrunoBB 08/04/2015 14:07'!
initializeCache

	cache := OrderedCollection new.! !

!OrbeonServiceInteraction methodsFor: 'other' stamp: 'BrunoBB 08/04/2015 13:55'!
addToCache

	^self class cache add: self! !

!OrbeonServiceInteraction methodsFor: 'Accessing' stamp: 'BrunoBB 08/04/2015 13:54'!
headers
	^headers! !

!OrbeonServiceInteraction methodsFor: 'Updating' stamp: 'BrunoBB 08/04/2015 13:54'!
headers: newValue
	headers := newValue! !

!OrbeonServiceInteraction methodsFor: 'Accessing' stamp: 'BrunoBB 08/04/2015 13:54'!
id
	^id! !

!OrbeonServiceInteraction methodsFor: 'Updating' stamp: 'BrunoBB 08/04/2015 13:54'!
id: newValue
	id := newValue! !

!OrbeonServiceInteraction methodsFor: 'other' stamp: 'BrunoBB 08/04/2015 14:03'!
initialize

	super initialize.

	headers := Dictionary new.
	parameters := Dictionary new.! !

!OrbeonServiceInteraction methodsFor: 'Accessing' stamp: 'BrunoBB 08/04/2015 13:54'!
parameters
	^parameters! !

!OrbeonServiceInteraction methodsFor: 'Updating' stamp: 'BrunoBB 08/04/2015 13:54'!
parameters: newValue
	parameters := newValue! !

!OrbeonServiceInteraction methodsFor: 'Accessing' stamp: 'BrunoBB 08/04/2015 13:54'!
valid
	^valid! !

!OrbeonServiceInteraction methodsFor: 'Updating' stamp: 'BrunoBB 08/04/2015 13:54'!
valid: newValue
	valid := newValue! !

!OrbeonServiceInteraction methodsFor: 'Accessing' stamp: 'BrunoBB 08/04/2015 13:54'!
xml
	^xml! !

!OrbeonServiceInteraction methodsFor: 'Updating' stamp: 'BrunoBB 08/04/2015 13:54'!
xml: newValue
	xml := newValue! !

Object subclass: #OrbeonStorage
	instanceVariableNames: 'app definitions'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

OrbeonStorage subclass: #OrbeonDataStorage
	instanceVariableNames: 'instances drafts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

!OrbeonDataStorage methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 11:54'!
addDraft: anOrbeon_Form_Data
	| draftsDictionary |

	draftsDictionary := drafts at: anOrbeon_Form_Data form ifAbsentPut: [Dictionary new].
	
	^draftsDictionary at: anOrbeon_Form_Data document_id put: anOrbeon_Form_Data! !

!OrbeonDataStorage methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 11:56'!
addInstance: anOrbeon_Form_Data
	| instanceDictionary |

	instanceDictionary := instances at: anOrbeon_Form_Data form ifAbsentPut: [Dictionary new].
	
	^instanceDictionary at: anOrbeon_Form_Data document_id put: anOrbeon_Form_Data! !

!OrbeonDataStorage methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 11:57'!
addSavedDefinition: anOrbeon_Form_Data
	"In Orbeon when a Form Definition is saved then is stored as <Orbeon_Form_Data> only after being published an instance of <Orbeon_Form_Definition> is created.
	Here we are saving a definition (isDefinition=true) not published yet"
	| savedCollection |

	savedCollection := definitions at: anOrbeon_Form_Data form ifAbsentPut: [Dictionary new].
	
	^savedCollection at: anOrbeon_Form_Data document_id put: anOrbeon_Form_Data! !

!OrbeonDataStorage methodsFor: 'Accessing' stamp: 'BrunoBB 08/16/2015 11:53'!
drafts
	^drafts! !

!OrbeonDataStorage methodsFor: 'Updating' stamp: 'BrunoBB 08/16/2015 11:53'!
drafts: newValue
	drafts := newValue! !

!OrbeonDataStorage methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 13:31'!
getAllFormDefinitionsOf: formName

	^definitions at: formName ifAbsent: [#()]! !

!OrbeonDataStorage methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 12:21'!
getAllFormDraftsOf: formName

	^drafts at: formName ifAbsent: [#()]! !

!OrbeonDataStorage methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 13:31'!
getAllFormInstancesOf: formName

	^instances at: formName ifAbsent: [#()]! !

!OrbeonDataStorage methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 14:12'!
getAnyFormDefinitionWithId: id
	
	^self getAnyFormDefinitionWithId: id ifNone: [nil]! !

!OrbeonDataStorage methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 14:12'!
getAnyFormDefinitionWithId: id ifNone: aBlock
	
	^(definitions detect: [:eachDict | eachDict includesKey: id] ifNone: [^aBlock value]) at: id! !

!OrbeonDataStorage methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 12:13'!
getAnyFormDraftWithId: id

	^self getAnyFormDraftWithId: id ifNone: [nil]! !

!OrbeonDataStorage methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 12:13'!
getAnyFormDraftWithId: id ifNone: aBlock
	
	^(drafts detect: [:eachDict | eachDict includesKey: id] ifNone: [^aBlock value]) at: id! !

!OrbeonDataStorage methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 14:11'!
getAnyFormInstanceWithId: id
	
	^self getAnyFormInstanceWithId: id ifNone: [nil]! !

!OrbeonDataStorage methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 14:11'!
getAnyFormInstanceWithId: id ifNone: aBlock
	
	^(instances detect: [:eachDict | eachDict includesKey: id] ifNone: [^aBlock value]) at: id! !

!OrbeonDataStorage methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 14:14'!
getFormDefinition: formName withId: id 

	^self getFormDefinition: formName withId: id ifNone: [nil]! !

!OrbeonDataStorage methodsFor: 'definitions' stamp: 'BrunoBB 08/10/2015 14:14'!
getFormDefinition: formName withId: id ifNone: aBlock
	| definitionsDictionary |

	definitionsDictionary := definitions at: formName ifAbsent: [^aBlock value].
	
	^definitionsDictionary  at: id ifAbsent: [aBlock value]! !

!OrbeonDataStorage methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 12:00'!
getFormDraft: formName withId: id

	^self getFormDraft: formName withId: id ifNone: [nil]! !

!OrbeonDataStorage methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 11:59'!
getFormDraft: formName withId: id ifNone: aBlock
	| draftsDictionary |

	draftsDictionary := drafts at: formName ifAbsent: [^aBlock value].
	
	^draftsDictionary  at: id ifAbsent: [aBlock value]! !

!OrbeonDataStorage methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 14:14'!
getFormInstance: formName withId: id 

	^self getFormInstance: formName withId: id ifNone: [nil]! !

!OrbeonDataStorage methodsFor: 'instances' stamp: 'BrunoBB 08/10/2015 14:13'!
getFormInstance: formName withId: id ifNone: aBlock
	| instancesDictionary |

	instancesDictionary := instances at: formName ifAbsent: [^aBlock value].
	
	^instancesDictionary  at: id ifAbsent: [aBlock value]! !

!OrbeonDataStorage methodsFor: 'other' stamp: 'BrunoBB 08/16/2015 11:53'!
initialize

	super initialize.

	instances := Dictionary new.
	drafts := Dictionary new.! !

!OrbeonDataStorage methodsFor: 'instances' stamp: 'BrunoBB 08/13/2015 11:03'!
instanceKeys

	^instances keys! !

!OrbeonDataStorage methodsFor: 'Accessing' stamp: 'BrunoBB 08/10/2015 11:03'!
instances
	^instances! !

!OrbeonDataStorage methodsFor: 'Updating' stamp: 'BrunoBB 08/10/2015 11:03'!
instances: newValue
	instances := newValue! !

!OrbeonDataStorage methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 11:56'!
removeDraft: anOrbeon_Form_Data
	| draftsCollection |

	draftsCollection := drafts at: anOrbeon_Form_Data form ifAbsent: [^anOrbeon_Form_Data].
	
	^draftsCollection removeKey: anOrbeon_Form_Data document_id ifAbsent: [anOrbeon_Form_Data]! !

!OrbeonDataStorage methodsFor: 'drafts' stamp: 'BrunoBB 08/16/2015 15:27'!
removeDraftWithId: id in: formName
	| draftsCollection |

	draftsCollection := drafts at: formName ifAbsent: [^nil].
	
	^draftsCollection removeKey: id ifAbsent: [nil]! !

!OrbeonDataStorage methodsFor: 'instances' stamp: 'BrunoBB 08/16/2015 11:55'!
removeInstance: anOrbeon_Form_Data
	| instanceCollection |

	instanceCollection := instances at: anOrbeon_Form_Data form ifAbsent: [^anOrbeon_Form_Data].
	
	^instanceCollection removeKey: anOrbeon_Form_Data document_id ifAbsent: [anOrbeon_Form_Data]! !

!OrbeonDataStorage methodsFor: 'definitions' stamp: 'BrunoBB 08/16/2015 11:56'!
removeSavedDefinition: anOrbeon_Form_Data
	"In Orbeon when a Form Definition is saved then is stored as <Orbeon_Form_Data> only after being published an instance of <Orbeon_Form_Definition> is created.
	Here we are saving a definition (isDefinition=true) not published yet"
	| savedCollection |

	savedCollection := definitions at: anOrbeon_Form_Data form ifAbsent: [^anOrbeon_Form_Data].
	
	^savedCollection removeKey: anOrbeon_Form_Data document_id ifAbsent: [anOrbeon_Form_Data]! !

!OrbeonDataStorage methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 14:55'!
totalSize
	| totalSize |

	totalSize := 0.

	definitions do: [:each | totalSize := totalSize + each size].
	instances do: [:each | totalSize := totalSize + each size].

	^totalSize! !

OrbeonStorage subclass: #OrbeonDefinitionStorage
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Orbeon_Persistence'!

!OrbeonDefinitionStorage methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 11:34'!
addDefinition: anOrbeon_Form_Definition
	"The receiver stored the published definition <anOrbeon_Form_Definition>"
	| publishedCollection |

	publishedCollection := definitions at: anOrbeon_Form_Definition form ifAbsentPut: [OrderedCollection new].
	
	^publishedCollection add: anOrbeon_Form_Definition! !

!OrbeonDefinitionStorage methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 12:42'!
getLastDefinitionOf: formName

	^(definitions at: formName ifAbsent: [^nil]) last! !

!OrbeonDefinitionStorage methodsFor: 'other' stamp: 'BrunoBB 08/14/2015 12:34'!
getLastestVersionNumberOf: formName

	^(self getLastDefinitionOf: formName) 
	ifNil: [0]
	ifNotNil: [:def | def form_version].! !

!OrbeonDefinitionStorage methodsFor: 'other' stamp: 'BrunoBB 08/16/2015 18:44'!
removeAllDefinitionsNamed: formName
	"The receiver remove all form definitions names <formName>"

	^definitions removeKey: formName ifAbsent: [nil].! !

!OrbeonDefinitionStorage methodsFor: 'other' stamp: 'BrunoBB 08/16/2015 18:35'!
removeDefinition: anOrbeon_Form_Definition
	"The receiver remove the published definition <anOrbeon_Form_Definition>"
	| publishedCollection |

	publishedCollection := definitions at: anOrbeon_Form_Definition form ifAbsent: [^anOrbeon_Form_Definition].
	
	^publishedCollection remove: anOrbeon_Form_Definition ifAbsent: [anOrbeon_Form_Definition]! !

!OrbeonDefinitionStorage methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 14:54'!
totalSize
	| totalSize |

	totalSize := 0.

	definitions do: [:each | totalSize := totalSize + each size].

	^totalSize! !

!OrbeonStorage methodsFor: 'Accessing' stamp: 'BrunoBB 08/10/2015 11:01'!
app
	^app! !

!OrbeonStorage methodsFor: 'Updating' stamp: 'BrunoBB 08/10/2015 11:01'!
app: newValue
	app := newValue! !

!OrbeonStorage methodsFor: 'other' stamp: 'BrunoBB 08/13/2015 11:03'!
definitionKeys

	^definitions keys! !

!OrbeonStorage methodsFor: 'Accessing' stamp: 'BrunoBB 08/10/2015 11:01'!
definitions
	^definitions! !

!OrbeonStorage methodsFor: 'Updating' stamp: 'BrunoBB 08/10/2015 11:01'!
definitions: newValue
	definitions := newValue! !

!OrbeonStorage methodsFor: 'other' stamp: 'BrunoBB 08/10/2015 12:33'!
initialize

	super initialize.

	definitions := Dictionary new.! !
